varflags

Struct Varflags

source
pub struct Varflags<E, B>(/* private fields */)
where
    E: Sized + Clone + TryFrom<Index<B>>,
    B: Bitset + Copy,
    B::Repr: From<E>;
Struct representing set over variants of some enum E implemented using bitworks bitset B.

Implementations

source

impl<E, B> Varflags<E, B>
where E: Sized + Clone + TryFrom<Index<B>>, B: Bitset + Copy, B::Repr: From<E>,

source

pub const NONE: Self = _

Empty set of variants.

source

pub const ALL: Self = _

Set of variants containing every variant of E.

source

pub const fn _from_inner(bitset: B) -> Self

Constructs Varflags from the inner Bitset.

source

pub fn contains(&self, variant: &E) -> bool

Returns true, if self contains a variant.

source

pub fn includes(&self, other: &Self) -> bool

Returns true, if self contains all variants of other.

source

pub fn intersects(&self, other: &Self) -> bool

Returns true, if both self and other share at least 1 variant.

source

pub fn variants<'a>(&'a self) -> impl Iterator<Item = E> + 'a

Returns iterator over variants contained in self.