pub struct Varflags<E, B>(/* private fields */)
where
E: Sized + Clone + TryFrom<Index<B>>,
B: Bitset + Copy,
B::Repr: From<E>;Expand description
Struct representing set over variants of some enum E implemented using bitworks bitset B.
Implementations
sourceimpl<E, B> Varflags<E, B>
impl<E, B> Varflags<E, B>
sourcepub const fn _from_inner(bitset: B) -> Self
pub const fn _from_inner(bitset: B) -> Self
Constructs Varflags from the inner Bitset.
sourcepub fn includes(&self, other: &Self) -> bool
pub fn includes(&self, other: &Self) -> bool
Returns true, if self contains all variants of other.
sourcepub fn intersects(&self, other: &Self) -> bool
pub fn intersects(&self, other: &Self) -> bool
Returns true, if both self and other share at least 1 variant.